/*
 * Resolver.h
 *
 *  Created on: Jan 13, 2015
 *      Author: mohajerani
 */

#ifndef RESOLVER_H_
#define RESOLVER_H_


#include "Utility.h"

typedef struct {
  // Gains.
  float Kp, Ki, Kd;
  float KiSpeed, KpSpeed;
  // i-term memory.
  float iTermTorque, iTermSpeed, iTermAngle;
  // Sampling time.
  float Ts;
} SpeedObserver;

/* ---------------------------------------------------------------------------------
 * High frequency voltage injection.
 */
void highVoltageInjection(float voltHF, float omegaHF, float theta, float Ts, float* sinHF, float* vCmdABC);

/* ---------------------------------------------------------------------------------
 * Speed observer.
 */
void speedObserverInit(float pGain, float iGain, float dGain, float Ts, Motor mtrParam, SpeedObserver* obs);
void speedObserver(float dTheta, float Ts, float eTrq, float* omegaEst, float* thetaEst, float* torqueEst, SpeedObserver* obs);

/* ---------------------------------------------------------------------------------
 * Heterodyning demodulation for resolver offset learn.
 */
void resolverOffsetDemodulation(float iq, float sinHF, float demodGain, float* dTheta, Filter* resolverLPF, Filter* resolverBPF);

/* ---------------------------------------------------------------------------------
 * Resolver offset learn.
 */
void resolverOffset(float voltHF, float omegaHF, float Ts, float thetaResolver, float demodGain, float electricTrq, float* thetaOffset, float* thetaEst,
                    float* speedEst, float* torqueEst, float* iABC, float* vCmdABC, Filter* resolverLPF, Filter* resolverBPF, SpeedObserver* speedObserver);

void resolverOffsetInit(float voltHF, float omegaHF, float dampRatio, float cutoffLPF, float iGain, float pGain, float dGain, float Ts,
                        Motor mtrParam, float* demodGain, Filter* resolverLPF, Filter* resolverBPF, SpeedObserver* speedObserver);


#endif /* RESOLVER_H_ */
