/*
 * pwm.c
 *
 *  Created on: Dec 22, 2014
 *      Author: mohajerani
 */

#include "MathLib.h"
#include "PWM.h"

/* ---------------------------------------------------------------------------------
 *
 */
void voltageToDuty(float voltAlpha, float voltBeta, PWMMethod method, float thetaPF, float* dutyA, float* dutyB, float* dutyC) {

  // Voltage adjustment in overmodulation region through Holtz method.
  float voltAlphaAdj, voltBetaAdj;
  overMod(voltAlpha, voltBeta, &voltAlphaAdj, &voltBetaAdj);

  float thetaAdj, modAdj;
  alphaBetaToNormAngle(voltAlphaAdj, voltBetaAdj, &thetaAdj, &modAdj);

  float thetaSector;
  int sectorNum;
  sectorCalc(thetaAdj, &thetaSector, &sectorNum);

  // Duty-cycle calculation inside sector.
  float dutyR	 = TWO_SQRT_THREE * INV_PI * modAdj * sinTbl(PI_THIRD - thetaSector);
  float dutyRp1 = TWO_SQRT_THREE * INV_PI * modAdj * sinTbl(thetaSector);
  float duty07 = 1.0 - dutyR - dutyRp1;
  limitToMin(0.0, duty07);

  // Zero vector partitioning.
  float zeta0, zeta7;
  zeroPartition(method, thetaAdj, thetaPF, &zeta0, &zeta7);

  // ABC duty cycle calculation.
  dutyCalc(sectorNum, dutyR, dutyRp1, duty07, zeta0, zeta7, dutyA, dutyB, dutyC);
}

/* ---------------------------------------------------------------------------------
 *
 */
void zeroPartition(int method, float thetaSector, float thetaPF, float* zeta0, float* zeta7) {

	// Current angle.
	float thetaI = thetaWrap(thetaSector + thetaPF);

	// Current sector number and sector angle.
  int sectorNumI;
  float thetaSectorI;
	sectorCalc(thetaI, &thetaSectorI, &sectorNumI);

	// Zero vectors partitioning based on PWM method.
	switch (method) {
	case GDPWM:
		if (sectorNumI % 2 == 1) {
			*zeta0 = 1;
			*zeta7 = 0;
		}	else {
			*zeta0 = 0;
			*zeta7 = 1;
		}
		break;
	case DPWMMIN:
		*zeta0 = 0;
		*zeta7 = 1;
		break;
	case DPWMMAX:
		*zeta0 = 1;
		*zeta7 = 0;
		break;
	case SVPWM:
		// Fall through intended.
	default:
		*zeta0 = 0.5;
		*zeta7 = 0.5;
		break;
	}
}

/* ---------------------------------------------------------------------------------
 *
 */
void dutyCalc(int sectorNum, float dutyR, float dutyRp1, float duty07, float zeta0, float zeta7, float* dutyA, float* dutyB, float* dutyC) {
	float duty0 = zeta0 * duty07;
	float duty7 = zeta7 * duty07;

	switch (sectorNum) {
	case 1:
		*dutyA = 1 - duty0;
		*dutyB = duty7 + dutyRp1;
		*dutyC = duty7;
		break;
	case 2:
		*dutyA = duty7 + dutyR;
		*dutyB = 1 - duty0;
		*dutyC = duty7;
		break;
	case 3:
		*dutyA = duty7;
		*dutyB = 1 - duty0;
		*dutyC = duty7 + dutyRp1;
		break;
	case 4:
		*dutyA = duty7;
		*dutyB = duty7 + dutyR;
		*dutyC = 1 - duty0;
		break;
	case 5:
		*dutyA = duty7 + dutyRp1;
		*dutyB = duty7;
		*dutyC = 1 - duty0;
		break;
	case 6:
	default:
	  // Fall through intended.
		*dutyA = 1 - duty0;
		*dutyB = duty7;
		*dutyC = duty7 + dutyR;
// 	default:
// 		*dutyA = 1 - duty0;
// 		*dutyB = duty7 + dutyRp1;
// 		*dutyC = duty7;
		break;
	}
}
