/*
 * ResolverWobble.c
 *
 *  Created on: Jan 22, 2015
 *      Author: mohajerani
 */

#include "ResolverWobble.h"

/* ---------------------------------------------------------------------------------
 *
 */
void speedArrayUpdate(float rawSpeed, float rawTheta, float speedArrayAvg[], float beta[], int* speedConstant, float* speedAvg) {

  float dTheta = INV_W_ARRAY_LENGTH * TWO_PI;
  int binNum = thetaWrap(rawTheta) / dTheta;
  static int binNumOld = 0;
  static float speedArrayTemp[W_ARRAY_LENGTH][2];

  if (binNum > W_ARRAY_LENGTH) {
    binNum = W_ARRAY_LENGTH;
  }

  if ((binNumOld - binNum) > (W_ARRAY_LENGTH - 2)) {
    // A new rotation has started, process the previous rotation data-set.
    speedArrayProcess (speedArrayTemp, speedArrayAvg, beta, speedConstant, speedAvg);
  }

  speedArrayTemp[binNum][0] += rawSpeed;
  speedArrayTemp[binNum][1] += 1;

  binNumOld = binNum;
}

/* ---------------------------------------------------------------------------------
 *
 */
void betaGainUpdate(float speedArrayAvg[], float beta[], float speedAvg) {
  float speedAvgInverse = 1.0 / speedAvg;
  float betaTemp[W_ARRAY_LENGTH];
  float betaInvAvg = 0;
  int i = 0;

  for (i = 0; i < W_ARRAY_LENGTH; i++) {
    betaTemp[i] = speedArrayAvg[i] * speedAvgInverse;
    beta[i] += BETA_GAIN * (betaTemp[i] - beta[i]);
    betaInvAvg += 1.0 / beta[i];
  }

  for (i = 0; i < W_ARRAY_LENGTH; i++) {
    beta[i] = beta[i] * betaInvAvg * INV_W_ARRAY_LENGTH;
  }
}

/* ---------------------------------------------------------------------------------
 *
 */
void speedArrayProcess(float speedArrayTemp[][2], float speedArrayAvg[], float beta[], int* speedConstant, float* speedAvg) {
  int i = 0;

  for (i = 0; i < W_ARRAY_LENGTH; i++) {
    // Average speed for each angle bin.
    speedArrayAvg[i] = speedArrayTemp[i][0] / speedArrayTemp[i][1];
  }
  // Average speed for this rotation
  float speedSum = 0;
  for (i = 0; i < W_ARRAY_LENGTH; i++) {
    speedSum += speedArrayAvg[i];
  }
  *speedAvg = speedSum * INV_W_ARRAY_LENGTH;

  if (abs(speedArrayAvg[0] - speedArrayAvg[W_ARRAY_LENGTH-1]) < SPEED_ERR_THR) {
    // Constant speed operation, process the result.
    *speedConstant = 1;
    betaGainUpdate(speedArrayAvg, beta, *speedAvg);
  } else {
    // Variable speed operation, discard the result.
    *speedConstant = 0;
  }
  int j = 0;
  for (i = 0; i < W_ARRAY_LENGTH; i++) {
    for (j = 0; j < 2 ; j++) {
      speedArrayTemp[i][j] = 0;
    }
  }
}

