/*
 * RunMatlab.c
 *
 *  Created on: Jan 12, 2015
 *      Author: mohajerani
 */

#include "RunMatlab.h"


/* ---------------------------------------------------------------------------------
 *
 */
void funcMatlabPWM(double* in, double* out) {

  float dutyA, dutyB, dutyC;
  float voltAlpha = (float) in[0];
  float voltBeta = (float) in[1];
  float thetaPF = (float) in[2];
  PWMMethod method = (PWMMethod) in[3];

  voltageToDuty(voltAlpha, voltBeta, method, thetaPF, &dutyA, &dutyB, &dutyC);

  out[0] = (double) dutyA;
  out[1] = (double) dutyB;
  out[2] = (double) dutyC;
}

/* ---------------------------------------------------------------------------------
 *

void funcMatlabROL(double* in, double* out) {
  static int init = 1;
  static Filter resolverLPF;
  static Filter resolverBPF;
  static SpeedObserver speedObs;
  static Motor mtrParam;
  static float thetaEst = 0.0;
  static float demodGain = 0.0;

  float omegaHF = (float) in[0];
  float voltHF = (float) in[1];
  float dampRatio = (float) in[2];
  float cutoffLPF = (float) in[3];
  float iGain = (float) in[4];
  float pGain = (float) in[5];
  float dGain = (float) in[6];
  float Ts = (float) in[7];
  float Ld = (float) in[8];
  float Lq = (float) in[9];
  float B = (float) in[10];
  float J = (float) in[11];
  float thetaResolver = (float) in[12];
  float iABC[3] = {(float) in[13], (float) in[14], (float) in[15]};
  float electricTrq = 0.0;

  float speedEst = 0;
  float torqueEst = 0;
  float thetaOffset = 0;
  float vCmdABC[3] = {0, 0, 0};

  if (init) {
    init = 0;
    mtrParam.LdDynamic = Ld;
    mtrParam.LqDynamic = Lq;
    mtrParam.B = B;
    mtrParam.J = J;
    resolverOffsetInit (voltHF, omegaHF, dampRatio, cutoffLPF, iGain, pGain, dGain, Ts, mtrParam, &demodGain, &resolverLPF, &resolverBPF, &speedObs);
  } else {
    resolverOffset(voltHF, omegaHF, Ts, thetaResolver, demodGain, electricTrq, &thetaOffset, &thetaEst, &speedEst, &torqueEst, iABC, vCmdABC, &resolverLPF, &resolverBPF, &speedObs);
  }

  out[0] = (double) thetaEst;
  out[1] = (double) speedEst;
  out[2] = (double) vCmdABC[0];
  out[3] = (double) vCmdABC[1];
  out[4] = (double) vCmdABC[2];
}
 */
/* ---------------------------------------------------------------------------------
 *

void funcMatlabFilt(double* in, double* out) {
  static int init = 1;
  static float oldT0 = 0;
  static Filter filt;
  FilterType type = (FilterType) in[0];
  float cutoff = (float) in[1];
  float dampRatio = (float) in[2];
  float Ts = (float) in[3];

  if (init) {
    digitalFilterInit(type, cutoff, dampRatio, Ts, 1, &filt);
    init = 0;
    out[0] = (double) 0.0;
  } else {
    // Reinitialize the filter gains if there is a new Task0.
    if (Ts > oldT0 * 1.0100 || Ts < oldT0 * 0.9901 ) {
      digitalFilterInit(type, cutoff, dampRatio, Ts, 0, &filt);
    }
    float var = (double) in[4];
    float varFilt;

    digitalFilter(var, &varFilt, &filt);
    out[0] = (double) varFilt;
  }
  oldT0 = Ts;
}
 */

/* ---------------------------------------------------------------------------------
 *

void funcMatlabWobble(double* in, double* out, double* out2) {
  float thetaRaw = (float) in[0];
  float speedRaw = (float) in[1];
  static int speedConstant = 0;
  static float speedAvg = 0;
  static float speedAvgArray[W_ARRAY_LENGTH];
  static float beta[W_ARRAY_LENGTH];

  speedArrayUpdate(speedRaw, thetaRaw, speedAvgArray, beta, &speedConstant, &speedAvg);

  out[0] = (double) speedAvg;
  out[1] = (double) speedConstant;
  int i = 0;
  for (i = 0 ; i < 100 ; i++) {
    out2[i] = (double) beta[i];
  }
}
 */

/* ---------------------------------------------------------------------------------
 *

void funcMatlabResolverAC(double* in, double* out) {
  static int init = 1;
  static Filter omegaLP, omegaHP, omegaH1LP, omegaH2LP, omegaH4LP;

  float Ts = (float) in[0];
  float omegaDampRatio = (float) in[1];
  float omegaCutOff = (float) in[2];
  float harmonicDampRatio = (float) in[3];
  float harmonicCutOff = (float) in[4];
  float thetaR = (float) in[5];
  float omegaR = (float) in[6];

  if (init) {
    resolverWobbleRemovalInit(Ts, omegaDampRatio, omegaCutOff, harmonicDampRatio, harmonicCutOff, 1, &omegaLP, &omegaHP, &omegaH1LP, &omegaH2LP, &omegaH4LP);
    init = 0;
    out[0] = (double) 0.0;
    out[1] = (double) 0.0;
  } else {
    float omega, theta;
    resolverWobbleRemoval(omegaR, thetaR, &omega, &theta, &omegaLP, &omegaHP, &omegaH1LP, &omegaH2LP, &omegaH4LP);
    out[0] = (double) omega;
    out[1] = (double) theta;
  }
}
 */
/* ---------------------------------------------------------------------------------
 *

void funcMatlabSpeedFilt(double* in, double* out) {
  static int init = 1;
  static Filter omegaLP, omegaHP;

  float Ts = (float) in[0];
  float omegaDampRatio = (float) in[1];
  float omegaCutOff = (float) in[2];
  float omegaR = (float) in[3];

  if (init) {
    resolverSpeedFilterInit(Ts, omegaDampRatio, omegaCutOff, 1, &omegaLP, &omegaHP);
    init = 0;
    out[0] = (double) 0.0;
    out[1] = (double) 0.0;
  } else {
    float omegaWbl, omegaAvg;
    resolverSpeedFilter(omegaR, &omegaWbl, &omegaAvg, &omegaLP, &omegaHP) ;
    out[0] = (double) omegaWbl;
    out[1] = (double) omegaAvg;
  }
}
 */

  /* ---------------------------------------------------------------------------------
   *

  void funcMatlabHarmonicGains(double* in, double* out) {
    static int init = 1;
    static Filter omegaLP, omegaHP, omegaH1LP, omegaH2LP, omegaH4LP;

    float Ts = (float) in[0];
    float omegaDampRatio = (float) in[1];
    float omegaCutOff = (float) in[2];
    float harmonicDampRatio = (float) in[3];
    float harmonicCutOff = (float) in[4];
    float thetaR = (float) in[5];
    float omegaR = (float) in[6];

    if (init) {
      resolverWobbleRemovalInit(Ts, omegaDampRatio, omegaCutOff, harmonicDampRatio, harmonicCutOff, 1, &omegaLP, &omegaHP, &omegaH1LP, &omegaH2LP, &omegaH4LP);
      init = 0;
      out[0] = (double) 0.0;
      out[1] = (double) 0.0;
    } else {
      float omegaWbl, omegaAvg;
      resolverSpeedFilter(omegaR, &omegaWbl, &omegaAvg, &omegaLP, &omegaHP) ;

      float aH1, aH1gH1, phaseH1;
      float aH2, aH2gH2, phaseH2;
      float aH4, aH4gH4, phaseH4;
      rdcHarmonicGains(thetaR, omegaWbl, omegaAvg, &omegaH1LP, &omegaH2LP, &omegaH4LP, &aH1, &aH1gH1, &phaseH1, &aH2, &aH2gH2, &phaseH2, &aH4, &aH4gH4, &phaseH4);

      out[0] = (double) omegaWbl;
      out[1] = (double) omegaAvg;
      out[2] = (double) aH2gH2;
      out[3] = (double) phaseH2;
    }
  }
  */
