/*
 * 1/2D look up tables
 *
 *  Created on: Jan 19, 2015
 *      Author: Campbell
 */

/* ---------------------------------------------------------------------------------
 *
 */
/*
 * Table lookup with interpolation (1-D and 2-D).
 *
 * This is a 1/2-D table lookup facility.  Each routine looks up data in a table
 * structure, interpolating as needed between data points.  The 2-D version
 * looks up along 2 axes and interpolates in two dimensions.
*/
#include <math.h>
#include <stdio.h>
#include <stdbool.h>
#include "lookup.h"


float lookup1d (Table1d *t, float ix, int n)
{
  int i;

  if (ix > t[n-1].x)
  {
	  return t[n-1].y;
  }

  if (ix < t[0].x)
  {
	  return t[0].y;
  }

  for (i = 0; i < n-1; i++)
  {
	  if (t[i].x <= ix && t[i+1].x >= ix)
	  {
		  float x_low = t[i].x;
		  float y_low = t[i].y;
		  float diffx = t[i+1].x - t[i].x;
		  float diffy = t[i+1].y - t[i].y;
		  /* prevent to divide by 0*/
		  if (diffx == 0)
		       {
		         return t[i].y;
		       }
		  return y_low + (ix - x_low) * diffy / diffx;

	  }
  }
}

float lookup2d (float vecX[], float vecY[], float table2d[][25], int nrows, int ncols, float ix, float iy)
{
	int i,j;
	float col_low, col_high;

	  /* X axis coordinate lookup */
	if (ix > vecX[nrows-1])
	{
		ix = vecX[nrows-1];
		i = nrows-1;
	}
	else if (ix < vecX[0])
	{
		ix =vecX[0];
		i = 0;

	}
	else
	{
		for (i = 0; i < nrows - 1; ++i)
		    {
		      if (   ix >= vecX[i]
		          && ix <= vecX[i+1])
		      {
		        break;
		      }
		    }

	}
	  /* Y axis coordinate lookup */
	if (iy > vecY[ncols-1])
	{
		iy = vecY[ncols-1];
		j = ncols -1;
	}
	else if (iy < vecY[0])
	{
		iy =vecY[0];
		j = 0;

	}
	else
	{
		for (j = 0; j < ncols - 1; ++j)
		    {
		      if (   iy >= vecY[j]
		          && iy <= vecY[j + 1])
		      {
		        break;
		      }
		    }

	}
	{

			/* Difference between the two adjacent row values */
			float i_delta = vecX[i+1]-vecX[i];
			/* Difference between the two adjacent column values */
			float j_delta = vecY[j + 1] - vecY[j];

	        /* Low column value */
			float i_low = vecX[i];
	        /* Low row value */
			float j_low = vecY[j];
	        /* Interpolation results for the upper and lower rows */

	        if (i_delta == 0)
	        {
	          col_low = table2d[i][j];
	          col_high = table2d[i][j+1];
	        }
	        else
	        {
	        	col_low = table2d[i][j]+(table2d[i+1][j]- table2d[i][j])/i_delta*(ix-i_low);
	        	col_high = table2d[i][j+1]+(table2d[i+1][j+1]- table2d[i][j+1])/i_delta*(ix-i_low);
	        }

	        if (j_delta == 0)
	        {
	        	return col_low;
	        }
	        else
	        {
				return col_low + (col_high-col_low)/j_delta*(iy-j_low);
	        }

	}
}

