/** @file diag.h
*   @brief api Driver Definition File
*   @date 9.Jan.2015
*   @version 00.00.00
*   
*/
/*
can protocol
bootload/test functions
ram range 0x08000000 - 0x0807ffff (512K)

pc to target
0x75X lower nibble of address selects controller id

0x750
cmd/rsp 4 upper bits of byte 7 are mode

mode 0 - peek cmd

  byte 7      byte 6      byte 5      byte 4      byte 3      byte 2      byte 1      byte 0
   0x00        0x00        0x00        0x00        0x00        0x00        0x00        0x00
0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000

ex. peek 0x0801ff04
  byte 7      byte 6      byte 5      byte 4      byte 3      byte 2      byte 1      byte 0
   0x08        0x01        0xff        0x04        0x00        0x00        0x00        0x00
0000  1000  0000  0001  1111  1111  0000  0100  0000  0000  0000  0000  0000  0000  0000  0000



target to pc
0x76X lower nibble of address selects controller id

0x760
cmd/rsp 4 upper bits of byte 7 are mode

mode 0 - peek rsp

  byte 7      byte 6      byte 5      byte 4      byte 3      byte 2      byte 1      byte 0
   0x00        0x00        0x00        0x00        0x00        0x00        0x00        0x00
0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000  0000

ex. *0x0801ff04 = 0x98765432
  byte 7      byte 6      byte 5      byte 4      byte 3      byte 2      byte 1      byte 0
   0x08        0x01        0xff        0x04        0x98        0x76        0x54        0x32
0000  1000  0000  0001  1111  1111  0000  0100  1001  1000  0111  0110  0101  0100  0011  0010

*/

#ifndef __DIAG_H__
#define __DIAG_H__

#include "HL_hal_stdtypes.h"

#ifdef __cplusplus
extern "C" {
#endif

#define RAM_START 	(uint32 *) 0x08000000
#define RAM_END   	(uint32 *) 0x0807ffff

#define	PeekCmd	         ((uint8)0x00) /* byte 8, peek cmd            */
#define Poke08Cmd        ((uint8)0x01) /* byte 8, 08 bit poke cmd     */
#define Poke16Cmd        ((uint8)0x02) /* byte 8, 16 bit poke cmd     */
#define Poke32Cmd        ((uint8)0x03) /* byte 8, 32 bit poke cmd     */
#define PokeFCmd         ((uint8)0x04) /* byte 8, float  poke cmd     */
#define	ExistCmd         ((uint8)0x05) /* byte 8, kernal exists cmd   */
#define	LoadBootCmd      ((uint8)0x06) /* byte 8, load ram data ack   */
#define	LoadRamCmd       ((uint8)0x07) /* byte 8, load ram cmd        */
#define	EraseCmd         ((uint8)0x08) /* byte 8, erase ram cmd       */
#define	ResetCmd         ((uint8)0x09) /* byte 8, reset cmd           */
#define JumpLoadCmd      ((uint8)0x0a) /* byte 8, jump to loader cmd  */
#define OutStringCmd     ((uint8)0x0b) /* byte 8, string output cmd   */
#define DacGetCmd        ((uint8)0x0c) /* byte 8, get dac struct cmd  */

#define	PeekRsp          ((uint8)0x00) /* byte 8, peek code ack       */
#define Poke08Rsp        ((uint8)0x01) /* byte 8, 08 bit poke ack     */
#define Poke16Rsp        ((uint8)0x02) /* byte 8, 16 bit poke ack     */
#define Poke32Rsp        ((uint8)0x03) /* byte 8, 32 bit poke ack     */
#define PokeFRsp         ((uint8)0x04) /* byte 8, float  poke ack     */
#define	ExistRsp         ((uint8)0x05) /* byte 8, kernal exists ack   */
#define	LoadBootRsp      ((uint8)0x06) /* byte 8, load ram data ack   */
#define	LoadRamRsp       ((uint8)0x07) /* byte 8, load ram code ack   */
#define	EraseRsp         ((uint8)0x08) /* byte 8, erase ram code ack  */
#define	ResetRsp         ((uint8)0x09) /* byte 8, reset code ack      */
#define JumpLoadRsp      ((uint8)0x0a) /* byte 8, jump load ack       */
#define OutStringRsp     ((uint8)0x0b) /* byte 8, string output ack   */
#define DacGetRsp        ((uint8)0x0c) /* byte 8, dac struct ack      */

#define	ErrorRsp         ((uint8)0x0f) /* byte 8, error code          */


typedef struct
{
	unsigned int Data0 : 32;
	unsigned int Data1 : 32;
}
tCAN2Uints_;

typedef struct
{
    unsigned int Data    : 32; // 32 bit int data
    unsigned int Mode    : 4;  // 4 bit mode
    unsigned int Address : 28; // 32 bit address
}
tCANdiag_;

typedef union
{
	tCANdiag_    c;
	tCAN2Uints_  u;
}
tCANdiag;



/**@}*/
#ifdef __cplusplus
}
#endif /*extern "C" */

#endif
