/** @file HL_sys_main.c 
*   @brief Application main file
*   @date 9.Sep.2014
*   @version 04.01.00
*
*   This file contains an empty main function,
*   which can be used for the application.
*/

/* (c) Texas Instruments 2009-2013, All rights reserved. */

/* USER CODE BEGIN (0) */
/* USER CODE END */

/* Include Files */

#include "HL_sys_common.h"
#include "HL_system.h"

/* USER CODE BEGIN (1) */
#include "HL_sys_main.h"
#include "HL_gio.h"
#include "HL_het.h"
#include "HL_rti.h"
#include "HAL_API.h"
#include "sys.h"
#include "vx1000_tms570.h"
#include "tms570.h"
#include "project.h"
#include <math.h.>
boolean jumpLoad = false;

#define TASK2_RATE_MS (100)

/* USER CODE END */

/** @fn void main(void)
*   @brief Application main function
*   @note This function is empty by default.
*
*   This function is called after startup.
*   The user can use this function to implement the application.
*/

/* USER CODE BEGIN (2) */

// Data to be traced by the VX1100.

#pragma DATA_SECTION(counter50us, ".HAL_RamData")
#pragma DATA_SECTION(counter1ms, ".HAL_RamData")
#pragma DATA_SECTION(counter100ms, ".HAL_RamData")
#pragma DATA_SECTION(counterUnused, ".HAL_RamData")
#pragma DATA_SECTION(Task0ExecutionTime, ".HAL_RamData")
#pragma DATA_SECTION(Task1ExecutionTime, ".HAL_RamData")
#pragma DATA_SECTION(Task2ExecutionTime, ".HAL_RamData")
#pragma DATA_SECTION(CpuUtilization, ".HAL_RamData")
#pragma DATA_SECTION(Task0ExecutionMax, ".HAL_RamData")
#pragma DATA_SECTION(Task1ExecutionMax, ".HAL_RamData")
#pragma DATA_SECTION(Task2ExecutionMax, ".HAL_RamData")
#pragma DATA_SECTION(Task2ExecutionMax, ".HAL_RamData")

volatile unsigned char counter50us;
volatile unsigned char counter1ms;
volatile unsigned char counter100ms;
volatile unsigned char counterUnused;
volatile float Task0ExecutionTime;
volatile float Task1ExecutionTime;
volatile float Task2ExecutionTime;
volatile float CpuUtilization;
volatile float Task0ExecutionMax;
volatile float Task1ExecutionMax;
volatile float Task2ExecutionMax;
volatile float CpuUtilizationMax;


#pragma TASK(main)

/* USER CODE END */

/** @fn void main(void)
*   @brief Application main function
*   @note This function is empty by default.
*
*   This function is called after startup.
*   The user can use this function to implement the application.
*/

/* USER CODE BEGIN (2) */
//Periods in usecs
#define T0_PERIOD_US (50.0f)
#define T1_PERIOD_US (1000.0f)
#define T2_PERIOD_US (100000.0f)

#define T0_PER_T2 (T2_PERIOD_US / T0_PERIOD_US)
#define T1_PER_T2 (T2_PERIOD_US / T1_PERIOD_US)

/* USER CODE END */

void main(void)
{
/* USER CODE BEGIN (3) */
    int i;
    float actualTask1ExecTime, actualTask2ExecTime;

    //initialize the GIO driver
    gioInit();

	InitTestPointOutputs;
	CLR_FLG_00;				// Indicate entry to main

	//set pins 5, 6 and 7 of GIOB to outputs
	gioSetDirection(gioPORTB, 0xE0);

	// Initialize RTP/DMM.
	sysRtpDmmInit();

	// Initialize the ECU parameter structure.
	VX1000_INIT;

	counter50us = 0;
	counter1ms = 0;
	counter100ms = 0;
	counterUnused = 0;
	Task0ExecutionTime = 0;
	Task1ExecutionTime = 0;
	Task2ExecutionTime = 0;
	Task0ExecutionMax = 0;
	Task1ExecutionMax = 0;
	Task2ExecutionMax = 0;
	CpuUtilizationMax = 0;
	CpuUtilization = 0;
	//end of vector code

	// save interrupt vectors, flash -> ram
	// need to define AppID enum and put in appropriate .h
	// transfer_irq_vectors_from_flash_to_ram( AppID );
    for(i=0;i<0x20;i++)
    {
        ((char *)0x0807FF00)[i] =((char *)0x00010000)[i];
    }

	/* Pre-Init */
    canInit();
	etpwmInit();
	etpwmStartTBCLK();
    adcInit();

    //initialize RTI driver
    rtiInit();
	rtiStartCounter(rtiREG1, rtiCOUNTER_BLOCK0);
	rtiEnableNotification(rtiREG1, rtiNOTIFICATION_COMPARE0);

	//init all tasks
	AppTask0Init();
	AppTask1Init();
	AppTask2Init();


	/* Enable Interrupts */
	_enable_interrupt_();

	SET_FLG_00;				// Indicate completion of main, pre-schedule

	i = 0;

	/* Service Scheduler/Tasks */
	while(1)
	{
		if( jumpLoad )
		{
		    while( canIsTxMessagePending(canREG1, canMESSAGE_BOX9) );
			systemREG1->SYSECR = 0x00008000UL;  // sw reset
		}

		// idle loop
		IdleCount++;
		if( IdleCount > 1000000 )
		{
			TGL_LED2;
			IdleCount = 0;
		}

		if( (Task1Count - i) > TASK2_RATE_MS)
		{
			i = Task1Count;
			Task2();
			Task2Pending = 0;

			//need to subtract out time Task1 was interrupted by task 0
			actualTask1ExecTime = Task1ExecutionTime - Task1ExecutionTime/T0_PERIOD_US * Task0ExecutionTime;

			//need to subtract time Task 2 was interrupted by task 0 and 1
			actualTask2ExecTime = Task2ExecutionTime - (Task2ExecutionTime/T0_PERIOD_US * Task0ExecutionTime) - (Task2ExecutionTime/T1_PERIOD_US * actualTask1ExecTime);

			//this is calculated every T2
			CpuUtilization = 100 * ((Task0ExecutionTime * T0_PER_T2)
					       + (actualTask1ExecTime * T1_PER_T2)
					       + (actualTask2ExecTime))/(T2_PERIOD_US);

			if(CpuUtilization > CpuUtilizationMax)
				CpuUtilizationMax = CpuUtilization;
		}
	}

/* USER CODE END */
}

/* USER CODE BEGIN (4) */
unsigned long Task0Counter = 0;
unsigned long Task1Counter = 0;

//array of structures to store adc data
adcData_t adc_data_array[16];

//start of vector code
unsigned int *pRamSynch = (unsigned int*)TRACE_WINDOW_START;
unsigned int ramSynchCtr = 0;
extern unsigned long F_VarTest;
/* Task 0 */
void adcNotification(adcBASE_t *adc, uint32 group)
{
	unsigned i;
	unsigned long clock = 0;

	SET_FLG_01;
	gioSetBit( gioPORTB, 6, 1 );
	clock = SYS_CLK;

	counter50us++;

	//RAM synchronization
	if (ramSynchCtr >= RAM_SYNCH_CHUNKS) 
	{
		VX1000_EVENT(VX1000_EVENT_RAMSYNC_START);
		ramSynchCtr = 0;
		pRamSynch = (unsigned int*)TRACE_WINDOW_START;
	}

	for (i = 0; i < RAM_SYNCH_CHUNK_DWORDS; i++)
	{
	  gVX1000.RamSynchField = *pRamSynch++;
	  asm(" dsb");
	}

	ramSynchCtr++;

	VX1000_EVENT(0x1);

	Task0Count++;

	temp = adcGetData(adcREG1, adcGROUP0, adc_data_array);

#ifdef FAUX_APP
	faux_app_task0();
#else
	AppTask0();
#endif

	SetPWM( getpwmApercent(), getpwmBpercent(), getpwmCpercent() );

	//measure task 0 execution time
	Task0ExecutionTime = ((float) (SYS_CLK - clock)) * 0.1f;

	if(Task0ExecutionTime > Task0ExecutionMax)
		Task0ExecutionMax = Task0ExecutionTime;

	CLR_FLG_01;

		gioSetBit( gioPORTB, 6, 0 );
}

//HAL task 1 entry point
void rtiNotification(rtiBASE_t *rtiREG, uint32 notification)
{
	unsigned int t1temp;
	unsigned long clock = 0;

	gioSetBit( gioPORTB, 7, 1 );
	clock = SYS_CLK;
	counter1ms++;

	VX1000_EVENT(0x2);

	SET_FLG_02;
	Task1Active = 1;
	Task1Count++;

	//waste some time just for demonstration puposes
	t1temp = Task0Count;
	while((Task0Count - t1temp) < get_task1_fake_processing());

#ifdef FAUX_APP
	faux_app_task1();
#else
	AppTask1();
#endif

	Task1Active = 0;
	CLR_FLG_02;

	//measure task 1 execution time
	Task1ExecutionTime = ((float) (SYS_CLK - clock)) / 10.0f;

	if(Task1ExecutionTime > Task1ExecutionMax)
		Task1ExecutionMax = Task1ExecutionTime;

	gioSetBit( gioPORTB, 7, 0 );
}

void Task2( void )
{
	unsigned int t2temp;
	unsigned long clock = 0;

	gioSetBit( gioPORTB, 5, 1 );
	clock = SYS_CLK;
	counter100ms++;

	VX1000_EVENT(0x3);

	SET_FLG_03;
	Task2Active = 1;
	Task2Count++;

#ifdef FAUX_APP
	faux_app_task2();
#else
	AppTask2();
#endif

	t2temp = Task1Count;
	while( (Task1Count - t2temp) < get_task2_fake_processing() );

	if( (Task2Count % BLINK_RATE_IN_T2_CNTS) == 0 ) TGL_LED3;

	Task2Active = 0;
	CLR_FLG_03;

	//measure task 2 execution time
	Task2ExecutionTime = ((float) (SYS_CLK - clock)) / 10.0f;

	if(Task2ExecutionTime > Task2ExecutionMax)
		Task2ExecutionMax = Task2ExecutionTime;

	gioSetBit( gioPORTB, 5, 0 );
}


/* USER CODE END */
