/*----------------------------------------------------------------------------
| Defines for system settings
|-----------------------------------------------------------------------------
| Copyright (c) 2009 by Vector Informatik GmbH.  All rights reserved.
|---------------------------------------------------------------------------*/

#ifndef __SYS_H__
#define __SYS_H__


#include "project.h"
#include "tms570.h"


//
// Clock used by the application.
//
// (resolution: .1us/tick)

#define SYS_CLK            TMS570_RTI_FRC0



//
// PLL and Timer register settings for chosen frequency
//
#if defined SYS_PLL_16_TO_40_MHZ
// 40Mhz from 16Mhz
#define SYS_PLL_CNTL1      0x40868b00UL
#define SYS_PLL_CNTL2      0x0701ae5cUL
#define SYS_RTI_CPUC1      39UL

#elif defined SYS_PLL_16_TO_60_MHZ
// 60Mhz from 16Mhz
#define SYS_PLL_CNTL1      0x40037700UL
#define SYS_PLL_CNTL2      0x00000e00UL
#define SYS_RTI_CPUC1      59UL

#elif defined SYS_PLL_16_TO_80_MHZ
// 80Mhz from 16Mhz
#define SYS_PLL_CNTL1      0x40868b00UL
#define SYS_PLL_CNTL2      0x0701a65cUL
#define SYS_RTI_CPUC1      79UL

// 100Mhz from 16Mhz
#elif defined SYS_PLL_16_TO_100_MHZ
#define SYS_PLL_CNTL1      0x40868200UL
#define SYS_PLL_CNTL2      0x02809504UL
#define SYS_RTI_CPUC1      99UL

#elif
#error No system frequency chosen!
#endif



//
// RTP register settings for chosen port width.
//
// For all port widths the following seetings apply:
//  - halt CPU/DMA on FIFO overflow
//  - continuous RTPCLK enabled
//  - Trace Mode
//  - Prescaler: RTPCLK = HCLK
//
#if defined RTP_2BIT
#define SYS_RTP_PC0        0x00070003UL
#define SYS_RTP_GLBCTRL    0x0000006aUL

#elif defined RTP_4BIT
#define SYS_RTP_PC0        0x0007000fUL
#define SYS_RTP_GLBCTRL    0x0000016aUL

#elif defined RTP_8BIT
#define SYS_RTP_PC0        0x000700ffUL
#define SYS_RTP_GLBCTRL    0x0000026aUL

#elif defined RTP_16BIT
#define SYS_RTP_PC0        0x0007ffffUL
#define SYS_RTP_GLBCTRL    0x0001036aUL

#elif
#error No RTP port width!
#endif



//
// DMM register settings for chosen port width.
//

#if defined DMM_2BIT
#define SYS_DMM_PC0        0x0004000fUL

#elif defined DMM_4BIT
#define SYS_DMM_PC0        0x0004003fUL

#elif defined DMM_8BIT
#define SYS_DMM_PC0        0x000403ffUL

#elif defined DMM_16BIT
#define SYS_DMM_PC0        0x0007ffffUL

#elif
#error No DMM port width chosen!
#endif


//
// Prototypes
//

extern void sysRtiInit();
extern void sysRtpDmmInit();

// Assembler function prototypes
extern void _clearRMW();


#endif //__SYS_H__
