/*------------------------------------------------------------------------------- */
/* vx1000_tms570.h                                                                */
/* Program instrumentation for Vector VX with TMS570                              */
/* Version 0.5  2013-11-04                                                        */
/* Vector Informatik GmbH                                                         */
/*                                                                                */
/* Don't modify this file, parameters are defined in vx1000_tms570_cfg.h          */
/*------------------------------------------------------------------------------- */



#ifndef VX1000_TMS570_H
#define VX1000_TMS570_H



#define VX1000_FILE_VERSION_MAJOR  0
#define VX1000_FILE_VERSION_MINOR  5


#define VX1000_FILE_VERSION (((VX1000_FILE_VERSION_MAJOR) << 8) | (VX1000_FILE_VERSION_MINOR))


/*------------------------------------------------------------------------------ */
/* Datatypes */

typedef unsigned int   VX1000_UINT32;
typedef unsigned short VX1000_UINT16;
typedef unsigned char  VX1000_UINT8;
typedef signed int     VX1000_INT32;
typedef signed short   VX1000_INT16;
typedef signed char    VX1000_INT8;
typedef int            VX1000_INT;
typedef long           VX1000_LONG;   /* needed for sizeof expression */
typedef char           VX1000_CHAR;   /* used by strings, __date etc; compile options may specify whether signed or not */
typedef float          VX1000_FLOAT;  /* needed for sizeof expression */
typedef double         VX1000_DOUBLE; /* needed for sizeof expression */
typedef long double    VX1000_LDOUBL; /* needed for sizeof expression */




//----------------------------------------------------------------------------------------------------
// VX1000 special events

#define VX1000_EVENT_RAMZERO_START  0x00010000UL
#define VX1000_EVENT_RAMSYNC_START  0x00010002UL
#define VX1000_EVENT_STRUCT_INIT    0x00040000UL




//----------------------------------------------------------------------------------------------------
// VX1000 ECU Parameter structure


#define VX1000_STRUCT_VERSION  3
#define VX1000_STRUCT_MAGIC    0xFEC70A08
  
typedef struct
{
  VX1000_UINT32   EventNumber;         /* 0x00 */
  VX1000_UINT32   EventTimestamp;
  VX1000_UINT32   MagicId;
  VX1000_UINT32   Version;
  VX1000_UINT32   GetIdPtr;            /* 0x10 */
  VX1000_UINT32   GetIdLen;
  VX1000_UINT32   XcpMailboxPtr;
  VX1000_UINT32   StimCtrlPtr;
  VX1000_UINT32   RamSynchField;       /* 0x20 */
} VX1000_STRUCT_T;

#define VX1000_STRUCT_DATA volatile VX1000_STRUCT_T gVX1000;

extern VX1000_STRUCT_DATA

//----------------------------------------------------------------------------------------------------
// User macros for VX1000 initialisation

#define VX1000_INIT {\
  gVX1000.EventTimestamp = 0; \
  gVX1000.MagicId = VX1000_STRUCT_MAGIC; \
  gVX1000.Version = VX1000_STRUCT_VERSION; \
  gVX1000.GetIdPtr = 0; \
  gVX1000.GetIdLen = 0; \
  gVX1000.XcpMailboxPtr = 0; \
  gVX1000.StimCtrlPtr = 0; \
  VX1000_EVENT(VX1000_EVENT_STRUCT_INIT)};


//----------------------------------------------------------------------------------------------------
// User macros for DAQ

// Trigger an event without ECU timestamp.
#define VX1000_EVENT(x) \
  gVX1000.EventNumber = (x); \
  asm(" dsb");


#endif
// VX1000_TMS570_H
