/*----------------------------------------------------------------------------
| System functions
|-----------------------------------------------------------------------------
| Copyright (c) 2009 by Vector Informatik GmbH.  All rights reserved.
|---------------------------------------------------------------------------*/

#include "project.h"
#include "tms570.h"
#include "sys.h"


// Imported functions
extern void __TI_auto_init();
extern void main();



void _sys_startup() {

  _clearRMW();

  // Global reset to the peripheral
  TMS570_SYS_CLKCNTL &= 0xfffffeffUL;

  // Flash pipeline on with 1 wait state
  TMS570_FL_RDCNTL = 0x00000101UL;
  // Flash parity off
  TMS570_FL_EDACCTRL1 = 0x00000005UL;

  // PLL configuration
  TMS570_SYS_PLLCTL1 = SYS_PLL_CNTL1; 
  TMS570_SYS_PLLCTL2 = SYS_PLL_CNTL2; 

  // VCLK1/VCLK2 prescaler (VCLK = HCLK)
  TMS570_SYS_CLKCNTL = 0x00000000UL;

  // Enabling the peripherals
  TMS570_SYS_CLKCNTL |= 0x100UL;

  // Setting the Peripherals out of powerdown mode
  TMS570_PCR_PSPWRDWNCLR0 = 0xffffffffUL;
  TMS570_PCR_PSPWRDWNCLR1 = 0xffffffffUL;
  TMS570_PCR_PSPWRDWNCLR2 = 0xffffffffUL;
  TMS570_PCR_PSPWRDWNCLR3 = 0xffffffffUL;

  // 0 RAM waitstates
  TMS570_SYS_RAMGCR = 0x00000000UL;

  // Enable Clock Source 1 (PLL)
  TMS570_SYS_CSDIS = 0xccUL;

  // Wait until PLL Clock Source is valid
  while(!(TMS570_SYS_CSVSTAT & 0x2UL));

  // Select PLL as Clock Source for HCLK,VCLK
  TMS570_SYS_GHVSRC	= 0x1UL;

  // Set all interrupt sources to trigger an IRQ and not a FIQ/NMI.
  TMS570_VIM_FIRQPR0 = 0;
  TMS570_VIM_FIRQPR1 = 0;

  // Clear all interrupt mask bits.
  TMS570_VIM_REQMSKCLR0 = 0xffffffffUL;
  TMS570_VIM_REQMSKCLR0 = 0xffffffffUL;

  // Set the clock source for the RTI module to VCLK without a divider.
  TMS570_SYS_RCLKSRC = 0x00090009;

  // Call the TI library to auto-initialize global data.
  __TI_auto_init();

  // call the application
  main();
}



void sysRtpDmmInit() {

 
  if (1) {

    // The RTP/DMM pins in the Gladiator devices are multiplexed with other
    // functions and have to be configured before RTP/DMM can be used.

    // Unlock PINMMRs.
    TMS570_IOMM_KICK0 = TMS570_KICK0_MAGIC;
    TMS570_IOMM_KICK1 = TMS570_KICK1_MAGIC;

    // Configure multiplexed DMM pins
#if defined DMM_4BIT
    TMS570_IOMM_PINMMR(25) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); // DMMDATA 2, 3
#elif defined DMM_8BIT
    TMS570_IOMM_PINMMR(12) = (1 << 0) | (1 << 8) | (1 << 16) | (1 << 25); // DMMDATA 7
    TMS570_IOMM_PINMMR(13) = (1 << 0) | (1 << 8) | (1 << 17) | (1 << 24); // DMMDATA 4
    TMS570_IOMM_PINMMR(26) = (1 << 0) | (1 << 8) | (1 << 17) | (1 << 25); // DMMDATA 2, 3
    TMS570_IOMM_PINMMR(27) = (1 << 1) | (1 << 9) | (1 << 16) | (1 << 24); // DMMDATA 5, 6
#elif defined DMM_16BIT
    TMS570_IOMM_PINMMR(12) = (1 << 0) | (1 << 8) | (1 << 16) | (1 << 25); // DMMDATA 7
    TMS570_IOMM_PINMMR(13) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 24); // DMMDATA 12, 8, 4
    TMS570_IOMM_PINMMR(26) = (1 << 0) | (1 << 8) | (1 << 17) | (1 << 25); // DMMDATA 2, 3
    TMS570_IOMM_PINMMR(27) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); // DMMDATA 5, 6, 9, 10
    TMS570_IOMM_PINMMR(28) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); // DMMDATA 11, 13, 14, 15
#endif

    // Configure multiplexed RTP pins.
#if defined RTP_2BIT
    TMS570_IOMM_PINMMR(15) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); //RTPCLK,ENA,SYNC, RTPDATA 0
    TMS570_IOMM_PINMMR(16) = (1 << 0) | (1 << 9) | (1 << 16) | (1 << 24); //RTPDATA 1
#elif defined RTP_4BIT
    TMS570_IOMM_PINMMR(15) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); //RTPCLK,ENA,SYNC, RTPDATA 0
    TMS570_IOMM_PINMMR(16) = (1 << 0) | (1 << 9) | (1 << 17) | (1 << 24); //RTPDATA 1, 2
    TMS570_IOMM_PINMMR(18) = (1 << 1) | (1 << 8) | (1 << 16) | (1 << 24); //RTPDATA 3
#elif defined RTP_8BIT
    TMS570_IOMM_PINMMR(11) = (1 << 0) | (1 << 9) | (1 << 16) | (1 << 24); //RTPDATA 7
    TMS570_IOMM_PINMMR(15) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); //RTPCLK,ENA,SYNC, RTPDATA 0
    TMS570_IOMM_PINMMR(16) = (1 << 0) | (1 << 9) | (1 << 17) | (1 << 24); //RTPDATA 1, 2
    TMS570_IOMM_PINMMR(18) = (1 << 1) | (1 << 8) | (1 << 17) | (1 << 24); //RTPDATA 3, 4
    TMS570_IOMM_PINMMR(20) = (1 << 1) | (1 << 9) | (1 << 16) | (1 << 24); //RTPDATA 5, 6
#elif defined RTP_16BIT
    TMS570_IOMM_PINMMR(9) =  (1 << 17); //RTPDATA 15
    TMS570_IOMM_PINMMR(10) = (1 << 1) | (1 << 9); //RTPDATA 14, 7
    TMS570_IOMM_PINMMR(4) = (1 << 9) | (1 << 17); //RTPCLK,ENA,SYNC
    TMS570_IOMM_PINMMR(3) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); //RTPDATA 0, 1, 2, 3
    TMS570_IOMM_PINMMR(2) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); //RTPDATA 4, 5, 6, 8
    TMS570_IOMM_PINMMR(1) = (1 << 1) | (1 << 9) | (1 << 17) | (1 << 25); //RTPDATA 9, 10, 11, 12
    TMS570_IOMM_PINMMR(0) = (1 << 25); //RTPDATA 13
#endif

    // Lock PINMMRs.
    TMS570_IOMM_KICK0 = 0;
  }





  //
  // RTP
  //

  // Disable RTP and put the module into reset.
  TMS570_RTP_GLBCTRL = 0x00010005UL;

  // Release the reset.
  TMS570_RTP_GLBCTRL = 0x00000005UL;

  // Enable trace fifo 1 and 2.
  TMS570_RTP_TRENA = 0x00000101UL;

  // Enable CPU/DMA write trace window at 0x08000000 with size 256k.
  TMS570_RTP_RAM1REG1 = 0x1b000000UL;
  TMS570_RTP_RAM2REG1 = 0x1b000000UL;

  // Set pins to functional mode.
  TMS570_RTP_PC0 = SYS_RTP_PC0;

  // Enable RTP data write trace.
  TMS570_RTP_GLBCTRL = SYS_RTP_GLBCTRL;


  //
  // DMM
  //

  // Disable DMM and put the module into reset.
  TMS570_DMM_GLBCTRL = 0x00010005UL;

  // Release the reset.
  TMS570_DMM_GLBCTRL = 0x00000005UL;

  // Enable DMM window at 0x08000000.
  TMS570_DMM_DEST0REG1 = 0x08000000UL;
  // Block size 256kB.
  TMS570_DMM_DEST0BL1 = 0x9;

  // Set ENA, DATA, CLK and SYN pins to functional mode.
  TMS570_DMM_PC0 = SYS_DMM_PC0;
  
  // Enable DMM data trace with a continuous DMMCLK.
  TMS570_DMM_GLBCTRL = 0x0004000aUL;
}



//
// Configure the free running counter 1 to run at 1us/tick.
//
void sysRtiInit() {
  // Disable the RTI counters.
  TMS570_RTI_GCTRL = 0UL;

  // Reset the up counter register 1.
  TMS570_RTI_UC1 = 0UL;

  // Set free running counter 1 frequency to 1 MHz according
  // to f(FRC1) = RTICLK/(CPUC1 + 1) with RTICLK = HCLK.
  TMS570_RTI_CPUC1 = SYS_RTI_CPUC1;

  // Start counter 1 with 'continue on suspend' enabled.
  TMS570_RTI_GCTRL = 0x8002UL;
 
}
