/*
 * trigTables.h
 *
 *  Created on: Feb 12, 2015
 *      Author: mohajerani
 */

#ifndef TRIGTABLES_H_
#define TRIGTABLES_H_

#define TRIGTBL_LENGTH          16383
#define TRIGTBL_THETA_STEP      0.000383542016065168
#define TRIGTBL_THETA_STEP_INV  2607.27627773143
#define TRIGTBL_ACOS_STEP       6.1035E-05

/* ---------------------------------------------------------------------------------
 * Trigonometric tables
 */
extern const float TRIGTBL_COS[];             // Sine table.
extern const float TRIGTBL_SIN[];             // Cosine table.
extern const float TRIGTBL_ACOS_THETA[];      // aCos Angle Table.
extern const float TRIGTBL_ACOS[];            // aCos Table.

#ifdef CONTROLLER_BUILD
/* ---------------------------------------------------------------------------------
 * inverse trig lookup table function.
 */
inline float aTrigTableLookup (float aTrig, const float* aTrigTable) {
  int binNum =  0.5 * (1 + aTrig) * TRIGTBL_LENGTH;

  if (binNum < 0)
  {
    binNum = 0;
  }
  else if (binNum >= TRIGTBL_LENGTH)
  {
    binNum = TRIGTBL_LENGTH - 1;
  }

  return (aTrigTable[binNum]);
}

/* ---------------------------------------------------------------------------------
 * trig lookup table function.
 */
inline float trigTableLookup (float theta, const float* trigTable) {
  int binNum = thetaWrap(theta) * TRIGTBL_THETA_STEP_INV;

  if (binNum < 0)
  {
    binNum = 0;
  }
  else if (binNum >= TRIGTBL_LENGTH)
  {
    binNum = TRIGTBL_LENGTH - 1;
  }

  return (trigTable[binNum]);
}
#else
#if TRIG_TABLES_C
/* ---------------------------------------------------------------------------------
 * inverse trig lookup table function.
 */
float aTrigTableLookup (float aTrig, const float* aTrigTable) {
  int binNum = 0.5 * (1 + aTrig) * TRIGTBL_LENGTH;

  if (binNum < 0) {
    binNum = 0;
  } else if (binNum > TRIGTBL_LENGTH) {
    binNum = TRIGTBL_LENGTH;
  }
  return (aTrigTable[binNum]);
}

/* ---------------------------------------------------------------------------------
 * trig lookup table function.
 */
float trigTableLookup (float theta, const float* trigTable) {
  int binNum = thetaWrap(theta) * TRIGTBL_THETA_STEP_INV;
  if (binNum < 0) {
    binNum = 0;
  } else if (binNum > TRIGTBL_LENGTH) {
    binNum = TRIGTBL_LENGTH;
  }
  return (trigTable[binNum]);
}
#else
extern float aTrigTableLookup (float aTrig, const float* aTrigTable);
extern float trigTableLookup (float theta, const float* trigTable);
#endif
#endif

/* ---------------------------------------------------------------------------------
 * Trigonometric lookup table functions
 */

/* ---------------------------------------------------------------------------------
 * sine
 */
#define sinTbl(thetaRads) trigTableLookup (thetaRads, TRIGTBL_SIN)


/* ---------------------------------------------------------------------------------
 * cosine
 */
#define cosTbl(thetaRads) trigTableLookup (thetaRads, TRIGTBL_COS)


/* ---------------------------------------------------------------------------------
 * arc cosine
 */
#define acosTbl(aCos) aTrigTableLookup (aCos, TRIGTBL_ACOS_THETA)



#endif /* TRIGTABLES_H_ */
